// ***************************************
// Plugin View code for SourceBoost IDE
// 
// Author(s): David Hobday
//
// Copyright (C) 2003-2010 Pavel Baranov
// Copyright (C) 2003-2010 David Hobday
// 
// This code may be freely used to develop
// Plugins for the SourceBoost IDE
// ***************************************

#include "stdafx.h"

#include "PluginApp.h"
#include <strstrea.h>
#include <math.h>

extern CPluginApp app;

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CPluginView

IMPLEMENT_DYNCREATE(CPluginView, CFormView)

CPluginView::CPluginView()
	: CFormView(CPluginView::IDD)
{
	//{{AFX_DATA_INIT(CPluginView)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
}

CPluginView::~CPluginView()
{
}

void CPluginView::DoDataExchange(CDataExchange* pDX)
{
	CFormView::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPluginView)
		// NOTE: the ClassWizard will add DDX and DDV calls here
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CPluginView, CFormView)
	//{{AFX_MSG_MAP(CPluginView)
	ON_WM_RBUTTONUP()
	ON_WM_VSCROLL()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPluginView diagnostics

#ifdef _DEBUG
void CPluginView::AssertValid() const
{
	CFormView::AssertValid();
}

void CPluginView::Dump(CDumpContext& dc) const
{
	CFormView::Dump(dc);
}
#endif //_DEBUG


BOOL CPluginView::Create( LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, CCreateContext* pContext )
{
	BOOL ok = CFormView::Create( lpszClassName, lpszWindowName, dwStyle, rect, pParentWnd, nID, pContext );
	
	if ( ok )
	{
		m_voltageSlider = (CSliderCtrl*)GetDlgItem( IDC_SLDR_VOLTAGE );
		m_voltageDisplay = (CStatic*)GetDlgItem( IDC_STATIC_VMV );
		
		// check controls all valid 
		if ( ! (m_voltageSlider && m_voltageDisplay) )
		{
			return FALSE;
		}
	}

	m_voltageSlider->SetRange( 0, 5000 );
	SetSliderV( 0 );

	return TRUE;
}


void CPluginView::DisplayV()
{
	strstream ss;	
	ss << app.data.GetV() << "mV" << ends;
	
	m_voltageDisplay->SetWindowText( ss.str() );
	ss.rdbuf()->freeze( 0 );
}

void CPluginView::SetSliderV( int Vmv )
{
	// control inverted to give max value at top
	m_voltageSlider->SetPos( 5000 - Vmv );
}

int CPluginView::GetSliderV()
{
	// control inverted to give max value at top
	return 5000 - m_voltageSlider->GetPos();
}

/////////////////////////////////////////////////////////////////////////////
// CPluginView message handlers

void CPluginView::OnDraw(CDC* pDC) 
{
	DisplayV();
}

void CPluginView::OnVScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar) 
{
	CFormView::OnVScroll(nSBCode, nPos, pScrollBar);
	
	// sliders all operate with lowest value when slider in lowest position
	// so we must invert there values
	
	if ( (CWnd*)pScrollBar == (CWnd*)m_voltageSlider )
	{
		app.data.SetV( GetSliderV() );
		DisplayV();
	}
}

void CPluginView::OnRButtonUp(UINT nFlags, CPoint point) 
{
	// pass on mouse button that invokes configure dialog
	ClientToScreen( &point );
	HWND parent = GetParent()->GetParent()->m_hWnd;
	GetParent()->GetParent()->PostMessage( WM_RBUTTONUP, nFlags, MAKELPARAM(point.x,point.y)  );
}

LRESULT CPluginView::WindowProc(UINT message, WPARAM wParam, LPARAM lParam) 
{
	switch( message )
	{
	// data object request that view updates it control from data's values
	case WMU_DATA_REQ_UPDATE:
		SetSliderV( app.data.GetV() );
		Invalidate();
		return 0;
	}
	
	return CFormView::WindowProc( message, wParam, lParam);
}
